@@ -11,15 +11,19 @@ export KEEPALIVED_VIRTUAL_ROUTER_ID=$(shuf -i 1-255 -n 1)
 
 function copy_logs {
     cp -rnL /var/lib/docker/volumes/kolla_logs/_data/* /tmp/logs/kolla/
-    # NOTE(SamYaple): Fix permissions for log extraction in gate
+    cp -rnL /etc/kolla/* /tmp/logs/kolla_configs/
+    cp -rvnL /var/log/* /tmp/logs/system_logs/
+
 
     if [[ -x "$(command -v journalctl)" ]]; then
-        journalctl --no-pager -u docker.service > /tmp/logs/kolla/docker.log
+        journalctl --no-pager -u docker.service > /tmp/logs/system_logs/docker.log
     else
-        cp /var/log/upstart/docker.log /tmp/logs/kolla/docker.log
+        cp /var/log/upstart/docker.log /tmp/logs/system_logs/docker.log
     fi
 
-    chmod -R 777 /tmp/logs/kolla/
+    # NOTE(SamYaple): Fix permissions for log extraction in gate
+    chmod -R 777 /tmp/logs/kolla /tmp/logs/kolla_configs /tmp/logs/system_logs
+    ara generate html /tmp/logs/playbook_reports/
 }
 
 function sanity_check {
@@ -65,10 +69,13 @@ kolla_install_type: "${KOLLA_TYPE}"
 kolla_internal_vip_address: "169.254.169.10"
 keepalived_virtual_router_id: "${KEEPALIVED_VIRTUAL_ROUTER_ID}"
 docker_restart_policy: "never"
+# NOTE(Jeffrey4l): use different a docker namespace name in case it pull image from hub.docker.io when deplying
+docker_namespace: "lokolla"
 network_interface: "${PRIVATE_INTERFACE}"
 neutron_external_interface: "fake_interface"
 enable_horizon: "no"
 enable_heat: "no"
+openstack_logging_debug: "True"
 EOF
 
     mkdir /etc/kolla/config/nova
@@ -107,8 +114,17 @@ write_configs
 ip l a fake_interface type dummy
 
 # Actually do the deployment
+tools/kolla-ansible -vvv prechecks
+# TODO(jeffrey4l): add pull action when we have a local registry
+# service in CI
 tools/kolla-ansible -vvv deploy
 tools/kolla-ansible -vvv post-deploy
 
 # Test OpenStack Environment
 sanity_check
+
+# TODO(jeffrey4l): make some configure file change and
+# trigger a real reconfigure
+tools/kolla-ansible -vvv reconfigure
+# TODO(jeffrey4l): need run a real upgrade
+tools/kolla-ansible -vvv upgrade
