@@ -20,15 +20,19 @@ function add_key {
 }
 
 function setup_disk {
-    sudo swapoff -a
-    sudo dd if=/dev/zero of=/swapfile bs=1M count=4096
-    sudo chmod 0600 /swapfile
-    sudo mkswap /swapfile
-    sudo /sbin/swapon /swapfile
+    if [ ! -f /swapfile ]; then
+        sudo swapoff -a
+        sudo dd if=/dev/zero of=/swapfile bs=1M count=4096
+        sudo chmod 0600 /swapfile
+        sudo mkswap /swapfile
+        sudo /sbin/swapon /swapfile
+    fi
 
-    sudo dd if=/dev/zero of=/docker bs=1M count=10240
-    losetup -f /docker
-    DEV=$(losetup -a | awk -F: '/\/docker/ {print $1}')
+    if [ ! -f /docker ]; then
+        sudo dd if=/dev/zero of=/docker bs=1M count=10240
+        losetup -f /docker
+        DEV=$(losetup -a | awk -F: '/\/docker/ {print $1}')
+    fi
 
     # Format Disks and setup Docker to use BTRFS
     sudo parted ${DEV} -s -- mklabel msdos
@@ -47,17 +51,31 @@ function setup_disk {
 # (SamYaple)TODO: Remove the path overriding
 export PATH="/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin"
 
+source /etc/lsb-release
+
 # Setup Docker repo and add signing key
-echo 'deb http://apt.dockerproject.org/repo ubuntu-trusty main' | sudo tee /etc/apt/sources.list.d/docker.list
+echo "deb http://apt.dockerproject.org/repo ubuntu-${DISTRIB_CODENAME} main" | sudo tee /etc/apt/sources.list.d/docker.list
 add_key
 sudo apt-get update
-sudo apt-get install -y --no-install-recommends 'docker-engine=1.12.*' btrfs-tools
+sudo apt-get -y install --no-install-recommends 'docker-engine=1.12.*' btrfs-tools
 
 sudo service docker stop
 setup_disk
-echo 'DOCKER_OPTS="-s btrfs"' | sudo tee /etc/default/docker
-sudo mount --make-shared /run
-sudo service docker start
+if [[ ${DISTRIB_CODENAME} == "trusty" ]]; then
+    echo 'DOCKER_OPTS="-s btrfs"' | sudo tee /etc/default/docker
+    sudo mount --make-shared /run
+    sudo service docker start
+else
+    sudo mkdir /etc/systemd/system/docker.service.d
+    sudo tee /etc/systemd/system/docker.service.d/kolla.conf << EOF
+[Service]
+ExecStart=
+ExecStart=/usr/bin/dockerd --storage-driver btrfs
+MountFlags=shared
+EOF
+    sudo systemctl daemon-reload
+    sudo systemctl start docker
+fi
 
 sudo docker info
 
